#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quic
version:              0.1.28
visibility:           public
id:                   quic-0.1.28-HrLWWYf52gQ2pOxHq4H8bI
key:                  quic-0.1.28-HrLWWYf52gQ2pOxHq4H8bI
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             QUIC
description:
    Library for QUIC: A UDP-Based Multiplexed and Secure Transport

category:             Web
abi:                  a56dc2a98ffb2b6c920b2eb436654880
exposed:              True
exposed-modules:
    Network.QUIC Network.QUIC.Client Network.QUIC.Internal
    Network.QUIC.Server

hidden-modules:
    Network.QUIC.Client.Reader Network.QUIC.Client.Run
    Network.QUIC.Closer Network.QUIC.Common Network.QUIC.Config
    Network.QUIC.Connection Network.QUIC.Connection.Crypto
    Network.QUIC.Connection.Migration Network.QUIC.Connection.Misc
    Network.QUIC.Connection.PacketNumber Network.QUIC.Connection.Queue
    Network.QUIC.Connection.Role Network.QUIC.Connection.State
    Network.QUIC.Connection.Stream Network.QUIC.Connection.StreamTable
    Network.QUIC.Connection.Timeout Network.QUIC.Connection.Types
    Network.QUIC.Connector Network.QUIC.Crypto
    Network.QUIC.Crypto.Fusion Network.QUIC.Crypto.Keys
    Network.QUIC.Crypto.Nite Network.QUIC.Crypto.Types
    Network.QUIC.Crypto.Utils Network.QUIC.Event Network.QUIC.Exception
    Network.QUIC.Handshake Network.QUIC.IO Network.QUIC.Imports
    Network.QUIC.Info Network.QUIC.Logger Network.QUIC.Packet
    Network.QUIC.Packet.Decode Network.QUIC.Packet.Decrypt
    Network.QUIC.Packet.Encode Network.QUIC.Packet.Frame
    Network.QUIC.Packet.Header Network.QUIC.Packet.Number
    Network.QUIC.Packet.Token Network.QUIC.Parameters
    Network.QUIC.QLogger Network.QUIC.Qlog Network.QUIC.Receiver
    Network.QUIC.Recovery Network.QUIC.Recovery.Constants
    Network.QUIC.Recovery.Detect Network.QUIC.Recovery.Interface
    Network.QUIC.Recovery.LossRecovery Network.QUIC.Recovery.Metrics
    Network.QUIC.Recovery.Misc Network.QUIC.Recovery.PeerPacketNumbers
    Network.QUIC.Recovery.Persistent Network.QUIC.Recovery.Release
    Network.QUIC.Recovery.Timer Network.QUIC.Recovery.Types
    Network.QUIC.Recovery.Utils Network.QUIC.Sender
    Network.QUIC.Server.Reader Network.QUIC.Server.Run
    Network.QUIC.Stream Network.QUIC.Stream.Frag
    Network.QUIC.Stream.Misc Network.QUIC.Stream.Queue
    Network.QUIC.Stream.Reass Network.QUIC.Stream.Skew
    Network.QUIC.Stream.Table Network.QUIC.Stream.Types
    Network.QUIC.TLS Network.QUIC.Types Network.QUIC.Types.Ack
    Network.QUIC.Types.CID Network.QUIC.Types.Constants
    Network.QUIC.Types.Error Network.QUIC.Types.Exception
    Network.QUIC.Types.Frame Network.QUIC.Types.Info
    Network.QUIC.Types.Integer Network.QUIC.Types.Packet
    Network.QUIC.Types.Queue Network.QUIC.Types.Resumption
    Network.QUIC.Types.Time Network.QUIC.Utils Network.QUIC.Windows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/quic-0.1.28
library-dirs:         /usr/lib/ghc-9.6.6/site-local/quic-0.1.28
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/quic-0.1.28
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quic
hs-libraries:         HSquic-0.1.28-HrLWWYf52gQ2pOxHq4H8bI
depends:
    array-0.5.6.0 base-4.18.2.1
    base16-bytestring-1.0.2.0-KkKTvweYtUjAEl7m2QLWFY
    bytestring-0.11.5.3 containers-0.6.7
    crypto-token-0.1.2-CtqSaCgrz20KfbN5YxSZEf
    crypton-1.0.5-ISaCEA7WOGuAiZSS5ibrwY
    crypton-x509-1.7.7-61hDuVrJRCRBiKHXcxYTtj
    crypton-x509-system-1.6.8-InHh8dHws42hsNSUa59d5
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc
    fast-logger-3.2.4-B4aHrB3bxM7EPhajFP3w9T filepath-1.4.300.1
    iproute-1.7.15-KfthO9WyCMI6N1Y86uw5VQ
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-9nB9sbnLDjyBVIWLW7TDGb
    network-byte-order-0.1.7-KOrHLkTNWo52qSQao8kAgk
    network-control-0.1.4-ApVRT3YUwsV5mmsdVKOOrp
    network-udp-0.0.0-Ay54NxKNvj84J7EUnS27xa
    random-1.2.1.3-FxwYxgjgoojJKMc450MWAC
    serialise-0.2.6.1-AnsUhULKqJ4IXxJL5hh3pq stm-2.5.1.0
    tls-2.0.6-KODXqScNPtDErnnkyIokYw
    unix-time-0.4.17-EYnTI5w33YS1vnTxAEO4UG
    unliftio-0.2.25.1-95hsWJFispi2AzgK8xFJw
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/haskell-quic/html/quic.haddock
haddock-html:         /usr/share/doc/haskell-quic/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

